==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_en.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")

dialogId("tru-m-co", "font_small", "What?")

dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")

dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")

dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")

dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")

dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")

dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")

dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")

dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")

dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")

dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")

dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")

dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")

dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")

dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")

dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")

dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")

dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")

dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")

dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")

dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")

dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_en.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")

dialogId("tru-m-co", "font_small", "What?")

dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")

dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")

dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")

dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")

dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")

dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")

dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")

dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")

dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")

dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")

dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")

dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")

dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")

dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")

dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")

dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")

dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")

dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")

dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")

dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")

dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
